
<!--
This is a short README for your routine, you can add any extra
documentation or examples that a user might want to see when
viewing the documentation at https://mozilla.github.io/bigquery-etl

You can embed an SQL file into your README using the following
syntax:

@sql(../../norm/examples/fenix_app_info.sql)
-->

